# QuasarCode

[![PyPI - Version](https://img.shields.io/pypi/v/QuasarCode.svg)](https://pypi.org/project/QuasarCode)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/QuasarCode.svg)](https://pypi.org/project/QuasarCode)

A general purpose library for Python applications.

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

### PyPI

```console
pip install QuasarCode
```

### From Source

Download the latest source code [here](https://github.com/QuasarX1/QuasarCode/tree/dev-python/QuasarCode_Python/src).

## License

`QuasarCode` is distributed under the terms of the [included license](./LICENSE.txt).
